@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2019
+/* Copyright (c) 1997-2023
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -24,15 +24,15 @@
 
 namespace polymake { namespace topaz {
 
-perl::Object h_induced_quotient(perl::Object p_in,const Set<int>& V_in,perl::OptionSet options)
+BigObject h_induced_quotient(BigObject p_in, const Set<Int>& V_in,OptionSet options)
 {
-   perl::Object p_out("SimplicialComplex");
+   BigObject p_out("SimplicialComplex");
 
-   const Array< Set<int> > C = p_in.give("FACETS");
+   const Array<Set<Int>> C = p_in.give("FACETS");
    const bool no_labels=options["no_labels"];
-   const int n_vert = p_in.give("N_VERTICES");
+   const Int n_vert = p_in.give("N_VERTICES");
 
-   int apex=n_vert;
+   Int apex = n_vert;
 
    if (!no_labels) {
       Array<std::string> L = p_in.give("VERTEX_LABELS");
@@ -44,12 +44,12 @@ perl::Object h_induced_quotient(perl::Object p_in,const Set<int>& V_in,perl::Opt
          label << "apex";
          std::string l=label.str(), ll=l;
          // creating vertex map
-         hash_map<std::string,int> map(L.size());
-         int count = 0;
+         hash_map<std::string, Int> map(L.size());
+         Int count = 0;
          for (const auto& label_in : L)
             map[label_in] = count++;
          // test if ll is unique
-         int i=0;
+         Int i = 0;
          while (map.find(ll) != map.end()) {
             ++i;
             label.str("");
@@ -68,8 +68,8 @@ perl::Object h_induced_quotient(perl::Object p_in,const Set<int>& V_in,perl::Opt
 
    // computing the subcomplex
    FacetList Quotient(C.begin(), C.end());
-   for (auto it=entire(C); !it.at_end(); ++it) {
-      Set<int> S=V_in*(*it);
+   for (auto it = entire(C); !it.at_end(); ++it) {
+      Set<Int> S = V_in * (*it);
       if (!S.empty()) {
          S+=apex;
          Quotient.insertMax(S);
@@ -85,16 +85,23 @@ perl::Object h_induced_quotient(perl::Object p_in,const Set<int>& V_in,perl::Opt
 }
 
 UserFunction4perl("# @category Producing a new simplicial complex from others"
-                  "# Let //C// be the given simplicial and A the subcomplex induced by"
+                  "# Let //C// be the given simplicial and //A// the subcomplex induced by"
                   "# the given //vertices//. Then this function produces a simplicial complex"
-                  "# homotopy equivalent to //C// mod A by adding the cone over A with"
-                  "# apex a to //C//."
+                  "# homotopy equivalent to C mod A by adding the cone over A with"
+                  "# apex a to C."
                   "# The label of the apex my be specified via the option //apex//."
                   "# @option Bool no_labels Do not create [[VERTEX_LABELS]]. default: 0"
                   "# @option String apex"
                   "# @param SimplicialComplex C"
                   "# @param Set<Int> vertices"
-                  "# @return SimplicialComplex",
+                  "# @return SimplicialComplex"
+                  "# @example The following takes C to be the suspension over a triangle and A to be the set of vertices of that triangle. The quotient induced is homotopy equivalent to a wedge of spheres."
+                  "# > $C = suspension(simplex(2) -> BOUNDARY);"
+                  "# > $t = h_induced_quotient($C, [0, 1, 2]);"
+                  "# > print $t -> HOMOLOGY;"
+                  "# | ({} 0)"
+                  "# | ({} 0)"
+                  "# | ({} 2)",                  
                   &h_induced_quotient,"h_induced_quotient(SimplicialComplex, $ { no_labels => 0, apex => undef})");
 } }
 
